#!/usr/bin/perl -w -IServer

#
#  Test that the Xen::Host module works as expected, this is a deliberately
# simple test module since we don't know if we're running under Xen or
# not - nor do we know the names of any running instances.
#
#

use Test::More qw( no_plan );

BEGIN{ use_ok( 'Xen::Host' ); }
require_ok( 'Xen::Host' );


#
#  Create a host with a funky name.
#
my $host1 = Xen::Host->new( name => "`f''`-o][}[]o1!!@#\$@*" );
isa_ok( $host1, "Xen::Host" );

#
#  Make sure the name is only ASCII
#
is( $host1->getName(), "foo1", "Host name is only alphanumeric" );



##
#
#  OK now we can test some simple operations which don't rely upon us
# using the Xm class.
#
##



#
#  Test IP address lookup, which uses DNS.  Wrap the test so that it
# fails gracefully if Net::DNS isn't available.
#
my $test = "use Net::DNS;";
my $dns  = 1;
eval( $test );
if ( $@ )
{
    $dns = 0;
}

SKIP: 
{
    #
    #  Run nslookup on www.steve.org.uk to find an IP address.
    #
    skip "Net::DNS not available", 2, if ( ! $dns );
    
    use Net::DNS;
    my $res   = Net::DNS::Resolver->new;
    my $query = $res->search("www.steve.org.uk");
    my $ip    = undef;

    if ($query) 
    {
	foreach my $rr ($query->answer) 
	{
	    next unless $rr->type eq "A";
	    $ip = $rr->address;
	}
    } 
    else
    {
	fail "query failed: " . $res->errorstring . "\n";
    }

    ok( defined( $ip ), "Ran 'nslookup www.steve.org.uk'" );

    #
    #  Now create a virtual host name and try to get the IP address.
    #
    my $host2 = Xen::Host->new( name => "www.steve.org.uk" );
    my $ip2   = $host2->getIPAddress();

    is( $ip, $ip2, "Xen::Host::getIPAddress matched the nslookup" );
}



TODO: {
    local $TODO = "Need to create a fake xen .cfg file first.";
    ok( 0, "Test the memory lookup works") ;
}
