#!/usr/bin/perl -w -IServer
#
#  Test that the Xen::Monitor module works as expected, listing files
# from the temporary directory.
#
#

use Test::More qw( no_plan );
use File::Temp;


BEGIN{ use_ok( 'Xen::Monitor' ); }
require_ok( 'Xen::Monitor' );



#
#  Create a temporary directory.
#
my $dir	    = File::Temp::tempdir( CLEANUP => 1 );
ok( -d $dir, "Created temporary directory" );

#
#  Create three configuration files :
#
#  dir/one.cfg
#  dir/two.cfg
#  dir/three.cfg
#
foreach my $name ( sort qw/ one two three/ ) 
{
    createFile($dir, $name );
    ok( -e $dir . "/" . $name . ".cfg", "Generated file exists: $name" );
}

#
#  Now try to create a new instance of Xen::Monitor.
#
my $monitor = Xen::Monitor->new( directory => $dir );
isa_ok( $monitor, "Xen::Monitor" );


#
#  Determine available instances.
#
my @available = $monitor->getAvailable();

#
#  Make sure we found the names we expected.
#
foreach my $avail ( @available )
{
    my $name = $avail->getName();
    ok( $name =~ /(one|two|three)/, " Found expected available host: $name" );
}





#
#  Create a Xen configuratione file in the given directory
#
sub createFile
{
    my ( $directory, $name ) = ( @_ );

    open( OUTPUT, ">", $directory . "/" . $name . ".cfg" )
      or die "Failed to create file : $directory/$name - $!";
    print OUTPUT<<EOF;
name = $name
memory = 128Mb;
EOF
    close ( OUTPUT );
}
